@@ -1,4 +1,4 @@
 """I/O conversion functions."""
-from .io_attributes import Attributes  # noqa
+from .io_attributes import Attributes, check_attrs  # noqa
 from .io_dependencies import (is_numba_installed)  # noqa
 from .io_syslog import set_log_level, logger, verbose  # noqa
